@@ -1,8 +1,18 @@
+"""
+A few wrappers and utilities for handling complex
+configuration objects.
+"""
+
 from collections import defaultdict
 
-seqs = (tuple, list, set, frozenset)
+SEQS = (tuple, list, set, frozenset)
 
 class ConfigDict(defaultdict):
+    """
+    A patchable dictionary like object that allows accessing items
+    as attributes.
+    """
+
     def __init__(self, initial=None):
         super(ConfigDict, self).__init__(ConfigDict)
         initial = initial or {}
@@ -10,10 +20,11 @@ class ConfigDict(defaultdict):
             self.__setitem__(key, value)
 
     def __setitem__(self, key, value):
+        # pylint: disable-msg=C0111
         def transform(primitive):
             if isinstance(primitive, dict):
                 return ConfigDict(primitive)
-            elif isinstance(primitive, seqs):
+            elif isinstance(primitive, SEQS):
                 seq = type(primitive)
                 return seq(transform(v) for v in primitive)
             else:
@@ -24,9 +35,41 @@ class ConfigDict(defaultdict):
         return super(ConfigDict, self).__getitem__(key)
 
     def copy(self):
+        """
+        Returns a copy of the config dict object.
+        """
         return ConfigDict(self)
 
     def patch(self, overrides):
+        """
+        Patches the config with the given overrides.
+
+        Example:
+
+        If the current dictionary looks like this:
+        a: 1,
+        b: {
+            c: 3,
+            d: 4
+        }
+
+        and `patch` is called with the following overrides:
+        b: {
+            d: 2,
+            e: 4
+        },
+        c: 5
+
+        then, the following will be the resulting dictionary:
+        a: 1,
+        b: {
+            c: 3,
+            d: 2,
+            e: 4
+        },
+        c: 5
+
+        """
         overrides = overrides or {}
         for key, value in overrides.iteritems():
             current = self.get(key)
@@ -39,7 +82,12 @@ class ConfigDict(defaultdict):
     __getattr__ = __getitem__
 
 
+# pylint: disable-msg=R0903
 class AutoPropDescriptor(object):
+    """
+    Descriptor for providing default values.
+    """
+
     def __init__(self, default_prop):
         self.default_prop = default_prop
         self.name = default_prop.__name__
@@ -58,9 +106,11 @@ class AutoPropDescriptor(object):
     def __set__(self, instance, value):
         self.__set_assigned__(instance, value)
 
-
+# pylint: disable-msg=R0903
 class AutoPropMetaClass(type):
-
+    """
+    Meta class for enabling autoprops.
+    """
     def __new__(mcs, cname, cbases, cattrs):
         autoprops = {name: member
                         for name, member in cattrs.iteritems()
@@ -70,12 +120,36 @@ class AutoPropMetaClass(type):
         return super(AutoPropMetaClass, mcs).__new__(
                 mcs, cname, cbases, cattrs)
 
-
+# pylint: disable-msg=R0903
 class AutoProp(object):
+    """
+    The base class for all objects supporting autoprops.
 
+    Usage:
+
+    class Project(AutoProp):
+
+        def __init__(self, config=None):
+            self.config = config or {}
+
+        @AutoProp.default
+        def source_dir(self):
+            return self.config.get('source')
+
+    p = Project({'source': 'test'})
+    p.source_dir
+    >>> 'test'
+    p.source_dir = 'xyz'
+    p.source_dir
+    >>> 'xyz'
+
+    """
     __metaclass__ = AutoPropMetaClass
 
     @staticmethod
-    def default(f):
-        f.autoprop = True
-        return f
+    def default(function):
+        """
+        Decorator for autoprops.
+        """
+        function.autoprop = True
+        return function
